# coding: utf-8
# vim: set fdm=indent ts=4 sw=4 sts=4 et tw=80 ai cc=+0 mouse=a nu : #

from setuptools import setup, find_packages

with open('msspec/version.py', 'r') as fd:
	content = fd.readlines()

version = "999.999"
for line in content:
	l = line.strip()
	if l.startswith('__version__'):
		version = l.split('=')[-1].strip(" \"")
		break

setup(name='msspec',
      version=version,
      author='Didier Sébilleau, Sylvain Tricot',
      author_email='sylvain.tricot@univ-rennes1.fr',
      maintainer='Sylvain Tricot',
      maintainer_email='sylvain.tricot@univ-rennes1.fr',
      url='https://msspec.cnrs.fr',
      description=('A multiple scattering package for sepectroscopies using '
                   'electrons to probe materials'),
      long_description="""MsSpec is a Fortran package to compute the
      cross-section of several spectroscopies involving one (or more)
      electron(s) as the probe. This package provides a python interface to
      control all the steps of the calculation.

      Available spectroscopies:
         * Photoelectron diffraction
         * Auger electron diffraction
         * Low energy electron diffraction
         * X-Ray absorption spectroscopy
         * Auger Photoelectron coincidence spectroscopy
         * Computation of the spectral radius""",
      download_url='https://msspec.cnrs.fr/downloads.html',
      # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Natural Language :: English',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'Operating System :: POSIX :: Linux',
        'Operating System :: MacOS :: MacOS X',
        'Programming Language :: Fortran',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Scientific/Engineering :: Physics',
        ],
      keywords='spectroscopy atom electron photon multiple scattering',
      license='GPL',

      include_package_data=True,
      packages=find_packages(include='msspec.*'),
      install_requires=[
	    'numpy',
        'ase',
        'h5py',
        'lxml',
        'pint',
        'terminaltables',
        'pycairo',
      ])
